@@ -55,7 +55,6 @@ import java.util.Date;
 import java.util.Iterator;
 import java.util.Queue;
 import org.apache.commons.lang.Validate;
-import org.apache.commons.logging.Log;
 import org.osgi.service.event.Event;
 import org.osgi.service.event.EventHandler;
 import com.openexchange.api2.FolderSQLInterface;
@@ -85,7 +84,7 @@ import com.openexchange.tools.session.ServerSessionAdapter;
  */
 public class AuditEventHandler implements EventHandler {
 
-    private static Log LOG = com.openexchange.log.Log.loggerFor(AuditEventHandler.class);
+    private static org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AuditEventHandler.class);
 
     private static final SimpleDateFormat logDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
 
@@ -101,7 +100,7 @@ public class AuditEventHandler implements EventHandler {
                 LOG.info("Using global Logging instance.");
             }
         } catch (final OXException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         }
     }
 
@@ -110,7 +109,7 @@ public class AuditEventHandler implements EventHandler {
      */
     @Override
     public void handleEvent(final Event event) {
-        Validate.notNull(event, "Event mustn't be null.");
+        Validate.notNull(event, "Event must not be null.");
 
         if (!LOG.isInfoEnabled()) {
             // Not allowed to log
@@ -131,7 +130,7 @@ public class AuditEventHandler implements EventHandler {
                 LOG.info(infoMsg);
             }
         } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         }
     }
 
@@ -217,8 +216,8 @@ public class AuditEventHandler implements EventHandler {
      * @throws OXException
      */
     protected void handleGroupwareEvent(Event event, StringBuilder log) throws OXException {
-        Validate.notNull(event, "Event mustn't be null.");
-        Validate.notNull(log, "StringBuilder to write to mustn't be null.");
+        Validate.notNull(event, "Event must not be null.");
+        Validate.notNull(log, "StringBuilder to write to must not be null.");
 
         final CommonEvent commonEvent = (CommonEvent) event.getProperty(CommonEvent.EVENT_KEY);
 
@@ -247,6 +246,10 @@ public class AuditEventHandler implements EventHandler {
             case Types.INFOSTORE:
                 handleInfostoreCommonEvent(commonEvent, context, log);
                 break ModuleSwitch;
+
+            case Types.FOLDER:
+                handleFolderCommonEvent(commonEvent, context, log);
+                break ModuleSwitch;
             }
         }
     }
@@ -274,6 +277,31 @@ public class AuditEventHandler implements EventHandler {
         }
     }
 
+    /**
+     * Handles appointment events.
+     *
+     * @param event - the {@link CommonEvent} that was received
+     * @param context - the {@link Context}
+     * @param log - the log to add information
+     * @throws OXException
+     */
+    protected void handleFolderCommonEvent(CommonEvent commonEvent, Context context, StringBuilder log) throws OXException {
+        Validate.notNull(commonEvent, "CommonEvent mustn't be null.");
+        Validate.notNull(log, "StringBuilder to write to mustn't be null.");
+
+        final FolderObject folder = (FolderObject) commonEvent.getActionObj();
+
+        log.append("OBJECT TYPE: FOLDER; ");
+        appendUserInformation(commonEvent.getUserId(), commonEvent.getContextId(), log);
+        log.append("CONTEXT ID: ").append(commonEvent.getContextId()).append("; ");
+        log.append("FOLDER ID: ").append(folder.getObjectID()).append("; ");
+        log.append("CREATED BY: ").append(UserStorage.getInstance().getUser(folder.getCreatedBy(), context).getDisplayName()).append(
+            "; ");
+        log.append("MODIFIED BY: ").append(UserStorage.getInstance().getUser(folder.getModifiedBy(), context).getDisplayName()).append(
+            "; ");
+        log.append("NAME: ").append(folder.getFolderName()).append("; ");
+    }
+
     /**
      * Handles appointment events.
      *
@@ -415,7 +443,7 @@ public class AuditEventHandler implements EventHandler {
                 retval = iter.next().getFolderName() + "/" + retval;
             }
         } catch (final OXException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         }
 
         return retval;
